@@ -7,7 +7,7 @@ __copyright__ = 'Copyright 2020'
 
 __license__ = "BSD 3-Clause License"
 
-__all__ = ['Testrelease']
+#__all__ = ['Testrelease']
 
 import os
 import sys
@@ -19,10 +19,10 @@ from .utils import (
     yell
     )
 
-
+'''
 class Testrelease():
 
     def __init__(self):
         print('Testrelease initialized.')
 
-
+'''
